package com.theevilroot.ithapi;

import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;

import java.util.ArrayList;
import java.util.List;

public class ITHApi {

    private static final String backendUrl = "http://52.48.142.75/backend/ITH.php";

    private final String username;
    private boolean isLogged = false;
    private int currentStory;

    public ITHApi(String username) {
        this.username = username;
    }

    public void auth() {
        try {
            String response = Jsoup.connect(backendUrl).data("task", "login").data("name", username).post().text();
            JsonObject obj = new JsonParser().parse(response).getAsJsonObject();
            isLogged = obj.get("isLogged").getAsBoolean();
            currentStory = obj.get("story").getAsInt();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public int getStory() {
        if (!isLogged)
            throw new RuntimeException("Not logged");
        return currentStory;
    }

    public Story loadCurrentStory() {
        if (!isLogged)
            throw new RuntimeException("Not logged");
        if (currentStory <= 0)
            currentStory = 1;
        return loadStory(currentStory);
    }

    public Story loadStory(int id) {
        try {
            Document doc = Jsoup.connect("http://ithappens.me/story/" + id).get();
            String title = doc.select(".story").select("h1").text();
            String date = doc.select(".date-time").text();
            String content = doc.select(".text").text();
            List<String> tags = new ArrayList<>();
            doc.select(".tags").select("ul").forEach(e -> tags.add(e.text()));
            return new Story(id, title, date, tags, content);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public Story increaseAndLoad() {
        if (currentStory <= 0)
            currentStory = 0;
        currentStory++;
        updateServerData();
        return loadCurrentStory();
    }

    public Story decreaseAndLoad() {
        if (currentStory <= 0 || currentStory == 1)
            currentStory = 2;
        currentStory--;
        updateServerData();
        return loadCurrentStory();
    }

    public Story setAndLoadStory(int index) {
        if(index <= 0)
            index = 1;
        currentStory = index;
        updateServerData();
        return loadCurrentStory();
    }

    public void updateServerData() {
        try {
            Jsoup.connect(backendUrl).data("task", "setStory").data("story", String.valueOf(currentStory)).data("name", username).post();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public boolean isLogged() {
        return isLogged;
    }


}
